import requests
from flask import render_template, url_for, jsonify, request
from azure.ai.textanalytics import TextAnalyticsClient
from azure.core.credentials import AzureKeyCredential
from app import app
import sys

@app.route('/')
def index():
    return render_template('index.html')


@app.route('/analyze-api', methods=['POST'])
def analyze_text_api():

    if request.method == 'POST':

        text = request.get_json()
        text = text['text']
        #text = "All of us do not have equal talent. But, all of us have an equal opportunity to develop our talents"
        
        url = (app.config['MICROSOFT_TEXT_ANALYTICS_URI'] +
                'text/analytics/v3.1-preview.1/sentiment')

        auth = {
            'Content-Type': 'application/json',
            'Ocp-Apim-Subscription-Key':
            app.config['MICROSOFT_TEXT_ANALYTICS_KEY'],
            'Accept': 'application/json'
        }

        data = {
            'documents': [{
                'language': 'en',
                'id': '1',
                'text': text,
            }]
        }

        try:

            response = requests.post(url, headers=auth, json=data)    
            result = response.json()['documents'][0]    
            result_dict = {
                'method' : 'API',
                'sentiment' : result['sentiment'],
                'positive_score' : result['confidenceScores']['positive'],
                'positive_neutral' : result['confidenceScores']['neutral'],
                'positive_negative' : result['confidenceScores']['negative'],
                'sentences' : []
            }

            sentenses = result['sentences']
            
            for sentence in sentenses:
                result_dict['sentences'].append({
                    'sentiment' : sentence['sentiment'],
                    'text' : sentence['text'],
                    'positive_score' : sentence['confidenceScores']['positive'],
                    'positive_neutral' : sentence['confidenceScores']['neutral'],
                    'positive_negative' : sentence['confidenceScores']['negative'],
                })
            
            return jsonify(result_dict)

        except:            
            return jsonify({"error": 'Internal Server Error'}), 500


@app.route('/analyze-sdk', methods=['POST'])
def analyze_text_sdk():

    if request.method == 'POST':
        try:
            endpoint = app.config['MICROSOFT_TEXT_ANALYTICS_URI']
            key = app.config['MICROSOFT_TEXT_ANALYTICS_KEY']

            text = request.get_json()
            text = text['text']
            #text = "All of us do not have equal talent. But, all of us have an equal opportunity to develop our talents"

            data = [text]

            credentials = AzureKeyCredential(key)
            text_analytics_client = TextAnalyticsClient(endpoint=endpoint, credential=credentials)

            result = text_analytics_client.analyze_sentiment(documents=data)[0]
            
            #print(result)
            result_dict = {
                'method' : 'SDK',
                'sentiment' : result.sentiment,
                'positive_score' : result.confidence_scores.positive,
                'positive_neutral' : result.confidence_scores.neutral,
                'positive_negative' : result.confidence_scores.negative,
                'sentences' : []
            }
            for index, sentence in enumerate(result.sentences):
                result_dict['sentences'].append({
                    'text' : sentence.text,
                    'sentiment' : sentence.sentiment,
                    'positive_score' : sentence.confidence_scores.positive,
                    'positive_neutral' : sentence.confidence_scores.neutral,
                    'positive_negative' : sentence.confidence_scores.negative,
                })
            return jsonify(result_dict)
        except:
            return jsonify({"error": 'Internal Server Error'}), 500